@@ -14,9 +14,8 @@ from typing import Any, Callable, Literal, Mapping
 from class_registry.base import RegistryKeyError
 from class_registry.registry import ClassRegistry
 from discord import Color, Embed, Forbidden, Guild, Interaction, Member, Message, NotFound, Permissions, Role, User, abc, ui
-from discord.abc import MISSING
 from discord.ext import tasks
-from discord.utils import utcnow
+from discord.utils import MISSING, utcnow
 from piccolo.columns import Or, Where
 from piccolo.engine.sqlite import SQLiteEngine
 from red_commons import logging
@@ -31,7 +30,7 @@ from typing_extensions import override
 from tidegear import Cog
 from tidegear import chat_formatting as cf
 from tidegear.exceptions import ArgumentTypeError, ConfigurationError, ContextError, NotFoundError, UnmetPermissionsError
-from tidegear.sentinel.db import Change, Moderation, PartialChannel, PartialGuild, PartialRole, PartialTargetable, PartialUser
+from tidegear.sentinel.db import TABLES, Moderation, PartialChannel, PartialGuild, PartialRole, PartialTargetable, PartialUser
 from tidegear.sentinel.exceptions import HandlerError, LoggedHandlerError, NotReadyError, UnsetError
 from tidegear.sentinel.moderation_type import ModerationType, moderation_type_registry
 from tidegear.types import GuildChannel, GuildMesseagableChannel
@@ -69,11 +68,16 @@ class SentinelCog(Cog):
         super().__init__(bot)
         self.moderation_type_registry: ClassRegistry[ModerationType] = moderation_type_registry
         self.db: SQLiteEngine = MISSING
-        self._db_path: pathlib.Path = cog_data_path(raw_name="TidegearSentinel")
+        self._sentinel_data_path: pathlib.Path = cog_data_path(raw_name="TidegearSentinel")
+        self._config_identifier = 294518358420750336
         self.sentinel_config: Config = Config.get_conf(
-            cog_instance=None, identifier=294518358420750336, cog_name="TidegearSentinel", force_registration=True
+            cog_instance=None, identifier=self._config_identifier, cog_name="TidegearSentinel", force_registration=True
+        )
+        self._unsafe_sentinel_config: Config = Config.get_conf(
+            cog_instance=None, identifier=self._config_identifier, cog_name="TidegearSentinel", force_registration=False
         )
         self._sentinel_logger: logging.RedTraceLogger = self.logger.getChild("sentinel")
+        self.tidegear_setup_file_logger(self._sentinel_logger, self._sentinel_data_path / "logs", "TidegearSentinel")
         self._sentinel_register_config()
 
         # If we don't override aiosqlite's logging level, it will spam the console with dozens of debug messages per query.
@@ -99,11 +103,13 @@ class SentinelCog(Cog):
 
         """
         await super().cog_load()
-        self._sentinel_logger.verbose("Using the following path to store the Sentinel SQLite database: %s", self._db_path)
+        self._sentinel_logger.verbose("Using the following path to store the Sentinel SQLite database: %s", self._sentinel_data_path)
         trace = True if self._sentinel_logger.level <= py_logging.DEBUG else False
         with set_env(key="PICCOLO_CONF", value="tidegear.sentinel.db.piccolo_conf", logger=self._sentinel_logger):
             self.db = await register_cog(
-                cog_instance=self._db_path, tables=[Change, Moderation, PartialChannel, PartialGuild, PartialRole, PartialUser], trace=trace
+                cog_instance=self._sentinel_data_path,
+                tables=TABLES,
+                trace=trace,
             )
 
         for moderation_type in self.sentinel_moderation_types:
@@ -145,7 +151,6 @@ class SentinelCog(Cog):
             Please ensure that you call `await super().cog_unload()` within your overridden method,
             as this method cleans up the Sentinel expiry loop and moderation type registry, and must be ran.
         """
-        await super().cog_unload()
         for moderation_type in self.sentinel_moderation_types:
             if moderation_type.key not in self.moderation_type_registry:
                 self._sentinel_logger.warning(
@@ -159,6 +164,9 @@ class SentinelCog(Cog):
             SentinelCog._sentinel_expiry_loop.cancel()
             self._sentinel_logger.debug("Cancelled expiry loop!")
 
+        self.tidegear_close_logger(self._sentinel_logger)
+        await super().cog_unload()
+
     @override
     async def red_delete_data_for_user(  # pyright: ignore[reportIncompatibleMethodOverride]
         self,
@@ -268,12 +276,13 @@ class SentinelCog(Cog):
         """
         return {name: cog for name, cog in self.bot.cogs.items() if isinstance(cog, SentinelCog)}
 
-    def get_sentinel_type_config(self, guild: Guild | int, moderation_type: ModerationType | type[ModerationType] | str) -> Group:
+    def get_sentinel_type_config(self, guild: Guild | int, moderation_type: ModerationType | type[ModerationType] | str, safe: bool = True) -> Group:
         """Retrieve a [`Group`][redbot.core.config.Group] that contains configuration for a specific moderation type.
 
         Args:
             guild: The Guild to fetch configuration for.
             moderation_type: The moderation type to fetch configuration for.
+            safe: Whether to use the `sentinel_config` attribute that has force registration or a config instance without force registration.
 
         Returns:
             The fetched configuration group. Consumed the same way as a `custom()` call.
@@ -288,7 +297,9 @@ class SentinelCog(Cog):
         else:
             key = moderation_type.key
 
-        return self.sentinel_config.custom("types", str(guild_id), key)
+        if safe:
+            return self.sentinel_config.custom("types", str(guild_id), key)
+        return self._unsafe_sentinel_config.custom("types", str(guild_id), key)
 
     async def get_sentinel_type_config_with_fallback(self, guild: Guild | int, moderation_type: ModerationType, attr: str) -> Any:
         """Retrieve a configuration value for a specific moderation type, falling back to the guild-level config if the type-level config is missing.
@@ -802,7 +813,7 @@ class SentinelCog(Cog):
         try:
             moderation_type = moderation.type
             for metadata in moderation_type.metadata:
-                if value := await metadata.fetch_from_moderation(moderation):
+                if value := await metadata.fetch_from_moderation(moderation, self.bot):
                     embed.description += f"\n{cf.bold(f'{title(metadata.human_name)}:')} {value}"
         except RegistryKeyError:
             pass
@@ -1062,19 +1073,19 @@ class SentinelCog(Cog):
                 try:
                     target = await moderation.target()
                 except UnsetError:
-                    self._internal_logger.exception("Moderation %i does not have a target!", moderation.id)
+                    self._sentinel_logger.exception("Moderation %i does not have a target!", moderation.id)
                     continue
                 except NotFoundError:
-                    self._internal_logger.exception("Could not find target for moderation %i!", moderation.id)
+                    self._sentinel_logger.exception("Could not find target for moderation %i!", moderation.id)
                     continue
 
                 try:
                     moderator = await moderation.moderator()
                 except UnsetError:
-                    self._internal_logger.exception("Moderation %i does not have a moderator!", moderation.id)
+                    self._sentinel_logger.exception("Moderation %i does not have a moderator!", moderation.id)
                     continue
                 except NotFoundError:
-                    self._internal_logger.exception("Could not find moderator for moderation %i!", moderation.id)
+                    self._sentinel_logger.exception("Could not find moderator for moderation %i!", moderation.id)
                     continue
 
                 value = (
@@ -1110,7 +1121,7 @@ class SentinelCog(Cog):
 
                 if moderation_type:
                     for meta in [meta for meta in moderation_type.metadata if meta.show_in_history]:
-                        if meta_value := await meta.fetch_from_moderation(moderation):
+                        if meta_value := await meta.fetch_from_moderation(moderation, self.bot):
                             value += f"{cf.bold(title(meta.human_name) + ':')} {meta_value}\n"
 
                 embed.add_field(name=f"Case {moderation.id:,} ({title(moderation.type_key)})", value=value, inline=inline)
