@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: 2025 cswimr <copyright@csw.im>
 # SPDX-License-Identifier: MPL-2.0
 
-from .tables import AbstractPartial, Change, Moderation, PartialChannel, PartialGuild, PartialRole, PartialTargetable, PartialUser
+from .tables import TABLES, AbstractPartial, Change, Moderation, PartialChannel, PartialGuild, PartialRole, PartialTargetable, PartialUser
 
 __all__ = [
     "AbstractPartial",
@@ -14,4 +14,5 @@ __all__ = [
     "PartialTargetable",
     "PartialGuild",
     "PartialRole",
+    "TABLES",
 ]
