@@ -12,6 +12,7 @@ import orjson
 import rich.repr
 from class_registry.base import RegistryKeyError
 from discord import Guild, Member, Object, Role, User, abc
+from piccolo.columns import Column
 from piccolo.columns.column_types import JSON, Boolean, ForeignKey, Integer, Serial, Text, Timestamptz, Varchar
 from piccolo.columns.defaults.timestamptz import TimestamptzNow
 from piccolo.table import Table as BaseTable
@@ -57,12 +58,18 @@ class Table(BaseTable):
         return True
 
     @overload
-    def json(self, *, string: Literal[False] = False, indent: bool = ..., options: int = ...) -> bytes: ...
+    def json(
+        self, *, columns: list[Column] | None = None, string: Literal[False] = False, encoding: str = ..., indent: bool = ..., options: int = ...
+    ) -> bytes: ...
 
     @overload
-    def json(self, *, string: Literal[True], indent: bool = ..., options: int = ...) -> str: ...
+    def json(
+        self, *, columns: list[Column] | None = None, string: Literal[True], encoding: str = ..., indent: bool = ..., options: int = ...
+    ) -> str: ...
 
-    def json(self, *, string: bool = False, indent: bool = False, options: int = 0) -> bytes | str:
+    def json(
+        self, *, columns: list[Column] | None = None, string: bool = False, encoding: str = "utf-8", indent: bool = False, options: int = 0
+    ) -> bytes | str:
         """Get a JSON representation of a table object.
 
         Utilizes a custom serializer that supports the following types, in addition to those supported
@@ -71,7 +78,9 @@ class Table(BaseTable):
         - [`Table`][tidegear.sentinel.db.tables.Table]
 
         Args:
+            columns: The columns to include in the output. Only passed columns will be included, does nothing if not provided.
             string: Whether or not to return a string. Avoids a manual decode step.
+            encoding: The encoding to use to decode the bytes returned by `orjson.dumps()`.
             indent: Whether or not to indent the output JSON. Don't use in performance-sensitive environments.
             options: Additional [options](https://github.com/ijl/orjson?tab=readme-ov-file#option) to pass into `orjson.dumps()`.
 
@@ -82,10 +91,15 @@ class Table(BaseTable):
         if indent:
             options |= orjson.OPT_INDENT_2
 
-        dump = orjson.dumps(self, default=self._json_serializer, option=options)
+        if columns is not None:
+            table_dictionary = self.to_dict(*columns)
+        else:
+            table_dictionary = self.to_dict()
+
+        dump = orjson.dumps(table_dictionary, default=self._json_serializer, option=options)
 
         if string:
-            return dump.decode("utf-8")
+            return dump.decode(encoding)
         return dump
 
     @classmethod
@@ -1061,3 +1075,6 @@ class Moderation(Table):
     async def next_case_number(cls) -> int:
         """Return the case number of the next moderation to be inserted into the database."""
         return await cls.count() + 1
+
+
+TABLES: list[type[BaseTable]] = [PartialGuild, PartialChannel, PartialRole, PartialUser, Change, Moderation]
