@@ -1,6 +1,5 @@
-# This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
-# If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
-# © 2025 cswimr
+# SPDX-FileCopyrightText: 2025 cswimr <copyright@csw.im>
+# SPDX-License-Identifier: MPL-2.0
 
 """This module contains exceptions used within Sentinel and consuming cogs."""
 
@@ -19,5 +18,9 @@ class UpsertError(TidegearError):
     """Raised whenever an upsert operation falis."""
 
 
+class UnsetError(TidegearError):
+    """Raised when attempting to access a database entry that is unset."""
+
+
 class NotReadyError(TidegearError):
     """Raised when attempting to expire a moderation case that isn't ready to expire."""
