@@ -6,6 +6,8 @@
 import functools
 import inspect
 import os
+import random
+import string
 import warnings
 from contextlib import contextmanager
 from importlib.resources import as_file, files
@@ -214,6 +216,23 @@ def get_asset_as_file(*, package: str = "tidegear.assets", filename: str, descri
         return discord.File(fp=path, filename=filename, description=description, spoiler=spoiler)
 
 
+def random_string(length: int, *, characters: str = string.ascii_lowercase + string.digits) -> str:
+    """Create a random string using the given characters.
+
+    Danger:
+        This uses the [`random`][] module. As such, it is **not** "random" enough to be considered cryptographically secure,
+        and should not be used to generate passwords, secret keys, security tokens, or anything of the sort.
+
+    Args:
+        length: The length of the string to generate.
+        characters: The characters to use in the string.
+
+    Returns:
+        The generated string.
+    """
+    return "".join(random.choices(population=characters, k=length))
+
+
 def title(string: str, /) -> str:
     """Replace any underscores in a string with spaces, then titlecase it.
 
@@ -258,6 +277,11 @@ async def send_error(
     return await messageable.send(content=content, **kwargs)
 
 
+async def noop() -> None:
+    """Do nothing. Serves as an asynchronous no-operation call."""
+    return
+
+
 @overload
 def get_kwarg(
     kwargs: dict[str, Any],
@@ -348,3 +372,36 @@ def truncate_string(string: str, max_length: int) -> str:
         truncated = truncated[:last_space]
 
     return truncated + "..."
+
+
+def recurse_modify(obj: Any, key: str, modify_fn: Callable[..., Any]) -> Any:
+    """Return a deep-copied version of an object with specific keys modified.
+
+    Traverses the given object recursively, supporting dictionaries, lists, tuples, and sets.
+    Whenever a dictionary key matches `key`, its value is replaced by the result of
+    calling `modify_fn` on the original value. All other values are copied and
+    processed recursively.
+
+    Args:
+        obj: The object to traverse. Can be a dict, list, tuple, set, or other type.
+        key: The dictionary key to search for.
+        modify_fn: A callable applied to the value of every matching key.
+
+    Returns:
+        A deep-copied version of `obj` where every matching key's value has been replaced.
+    """
+    if isinstance(obj, dict):
+        new_dict = {}
+        for k, v in obj.items():
+            if k == key:
+                new_dict[k] = modify_fn(v)
+            else:
+                new_dict[k] = recurse_modify(v, key, modify_fn)
+        return new_dict
+    if isinstance(obj, list):
+        return [recurse_modify(item, key, modify_fn) for item in obj]
+    if isinstance(obj, tuple):
+        return tuple(recurse_modify(item, key, modify_fn) for item in obj)
+    if isinstance(obj, set):
+        return {recurse_modify(item, key, modify_fn) for item in obj}
+    return obj
